"""
2x2 Geometry
============
"""

from FiberFusing import Geometry, Fused2, BackGround
from FiberFusing.fiber_catalogue import SMF28, get_silica_index

wavelength = 1.55e-6

air = BackGround(index=1.0)

clad = Fused2(
    fiber_radius=62.5e-6,
    fusion_degree=0.8,
    index=get_silica_index(wavelength=wavelength)
)

fibers = [
    SMF28(wavelength=wavelength, position=core) for core in clad.cores
]

geometry = Geometry(
    background=air,
    additional_structure_list=[clad],
    x_bounds='centering',
    y_bounds='centering',
    resolution=280
)

geometry.add_fiber(*fibers)

geometry.plot().show()


# -
